@@ -20,7 +20,6 @@ from pydantic import BaseModel, Field, field_validator
 from rich import box
 from rich.table import Table
 
-from hud.cli.utils.env_check import ensure_built, find_environment_dir
 from hud.settings import settings
 from hud.types import AgentType
 from hud.utils.env import resolve_env_vars
@@ -37,7 +36,6 @@ def _is_bedrock_arn(model: str | None) -> bool:
 
 if TYPE_CHECKING:
     from hud.agents.base import MCPAgent
-    from hud.types import Task
 
 logger = logging.getLogger(__name__)
 hud_console = HUDConsole()
@@ -93,14 +91,16 @@ _DEFAULT_CONFIG_TEMPLATE = """# HUD Eval Configuration
 [eval]
 # source = "hud-evals/SheetBench-50"
 # agent = "claude"
-# full = false
+# all = false  # Run all problems instead of just 1
 # max_concurrent = 30
 # max_steps = 10
 # group_size = 1
+# byok = false  # Remote only; use encrypted env vars on the platform.
 # task_ids = ["task_1", "task_2"]
 # verbose = true
 # very_verbose = true
 # auto_respond = true
+# gateway = false  # Route LLM API calls through HUD Gateway
 
 [agent]
 # allowed_tools = ["computer", "playwright"]
@@ -153,14 +153,17 @@ class EvalConfig(BaseModel):
         "source",
         "agent_type",
         "task_ids",
-        "full",
+        "all",
         "max_concurrent",
         "max_steps",
         "verbose",
         "very_verbose",
         "group_size",
+        "byok",
         "remote",
         "auto_respond",
+        "quiet",
+        "gateway",
     }
     # Fields loaded from [agent] section
     _AGENT_FIELDS: ClassVar[set[str]] = {"allowed_tools", "disallowed_tools"}
@@ -170,14 +173,17 @@ class EvalConfig(BaseModel):
     agent_type: AgentType | None = None
     model: str | None = None
     task_ids: list[str] | None = None
-    full: bool = False
+    all: bool = False  # Run all problems instead of just 1
     max_concurrent: int = 30
-    max_steps: int | None = None
+    max_steps: int = 10
     verbose: bool = False
     very_verbose: bool = False
-    auto_respond: bool | None = None  # Continue without prompting (default: True for --full)
+    auto_respond: bool | None = None  # Continue without prompting
     group_size: int = 1
+    byok: bool = False
     remote: bool = False
+    quiet: bool = False  # Suppress opening browser for eval links
+    gateway: bool = False  # Use HUD Gateway for LLM API calls
 
     # Base agent config (these merge with task's agent_config)
     allowed_tools: list[str] | None = None
@@ -205,6 +211,11 @@ class EvalConfig(BaseModel):
 
     def validate_api_keys(self) -> None:
         """Validate required API keys for the selected agent. Raises typer.Exit on failure."""
+        # BYOK requires remote execution (check before agent_type guard)
+        if self.byok and not self.remote:
+            hud_console.error("--byok requires --remote (BYOK only works with remote execution)")
+            raise typer.Exit(1)
+
         if self.agent_type is None:
             return
 
@@ -215,6 +226,14 @@ class EvalConfig(BaseModel):
                 raise typer.Exit(1)
             return
 
+        # Gateway mode only requires HUD_API_KEY
+        if self.gateway:
+            if not settings.api_key:
+                hud_console.error("HUD_API_KEY is required for gateway mode")
+                hud_console.info("Set it: hud set HUD_API_KEY=your-key-here")
+                raise typer.Exit(1)
+            return
+
         if self.agent_type == AgentType.OPENAI_COMPATIBLE:
             # Check both CLI --model and config file model
             config_model = self.agent_config.get("openai_compatible", {}).get("model")
@@ -267,26 +286,24 @@ class EvalConfig(BaseModel):
         agent_key = self.agent_type.value
         if agent_key in self.agent_config:
             agent_cfg = dict(self.agent_config[agent_key])
-            # Map user-facing 'model' to internal 'checkpoint_name'
-            if "model" in agent_cfg:
-                agent_cfg["checkpoint_name"] = agent_cfg.pop("model")
             kwargs.update(agent_cfg)
 
         # CLI --model always wins
         if self.model:
-            kwargs["checkpoint_name"] = self.model
+            kwargs["model"] = self.model
 
-        if self.agent_type == AgentType.OPENAI_COMPATIBLE:
+        # For gateway base_url, inject HUD API key if not already set
+        if self.agent_type == AgentType.OPENAI_COMPATIBLE and "api_key" not in kwargs:
             base_url = kwargs.get("base_url", "")
-            if "api_key" not in kwargs:
-                # Use HUD API key for gateway, otherwise fall back to OpenAI API key
-                if settings.hud_gateway_url in base_url:
-                    kwargs["api_key"] = settings.api_key
-                elif settings.openai_api_key:
-                    kwargs["api_key"] = settings.openai_api_key
+            if settings.hud_gateway_url in base_url and settings.api_key:
+                kwargs["api_key"] = settings.api_key
 
         # Auto-detect Bedrock when Claude is selected with a Bedrock ARN
-        if self.agent_type == AgentType.CLAUDE and _is_bedrock_arn(kwargs.get("checkpoint_name")):
+        # Check both model and checkpoint_name for ARN patterns
+        bedrock_arn_detected = _is_bedrock_arn(kwargs.get("model")) or _is_bedrock_arn(
+            kwargs.get("checkpoint_name")
+        )
+        if self.agent_type == AgentType.CLAUDE and bedrock_arn_detected:
             missing_aws = (
                 not settings.aws_access_key_id
                 or not settings.aws_secret_access_key
@@ -319,6 +336,50 @@ class EvalConfig(BaseModel):
         ):
             kwargs["validate_api_key"] = False
 
+        # Configure gateway mode - route LLM API calls through HUD gateway
+        if self.gateway:
+            hud_api_key = settings.api_key
+            if not hud_api_key:
+                raise typer.Exit(1)  # Already validated in validate_api_keys()
+
+            if self.agent_type == AgentType.CLAUDE:
+                from anthropic import AsyncAnthropic
+
+                kwargs["model_client"] = AsyncAnthropic(
+                    api_key=hud_api_key,
+                    base_url=settings.hud_gateway_url,
+                )
+                hud_console.info("🌐 Using HUD Gateway for Claude API")
+            elif self.agent_type in (AgentType.OPENAI, AgentType.OPERATOR):
+                from openai import AsyncOpenAI
+
+                kwargs["model_client"] = AsyncOpenAI(
+                    api_key=hud_api_key,
+                    base_url=settings.hud_gateway_url,
+                )
+                hud_console.info("🌐 Using HUD Gateway for OpenAI API")
+            elif self.agent_type == AgentType.OPENAI_COMPATIBLE:
+                from openai import AsyncOpenAI
+
+                kwargs["openai_client"] = AsyncOpenAI(
+                    api_key=hud_api_key,
+                    base_url=settings.hud_gateway_url,
+                )
+                hud_console.info("🌐 Using HUD Gateway for OpenAI-compatible API")
+            elif self.agent_type in (AgentType.GEMINI, AgentType.GEMINI_CUA):
+                from google import genai
+                from google.genai.types import HttpOptions
+
+                kwargs["model_client"] = genai.Client(
+                    api_key="PLACEHOLDER",
+                    http_options=HttpOptions(
+                        api_version="v1beta",
+                        base_url=settings.hud_gateway_url,
+                        headers={"Authorization": f"Bearer {hud_api_key}"},
+                    ),
+                )
+                hud_console.info("🌐 Using HUD Gateway for Gemini API")
+
         return kwargs
 
     @classmethod
@@ -398,12 +459,20 @@ class EvalConfig(BaseModel):
 
         overrides.update({k: v for k, v in cli_args.items() if v is not None and v is not False})
 
-        for k in ("full", "verbose", "very_verbose", "remote"):
+        for k in ("all", "verbose", "very_verbose", "remote", "quiet", "gateway"):
             if cli_args.get(k) is True:
                 overrides[k] = True
             elif k in overrides and cli_args.get(k) is False:
                 del overrides[k]
 
+        # --full is a shortcut for --all --auto-respond --max-steps 100
+        if overrides.get("full"):
+            overrides["all"] = True
+            if "auto_respond" not in overrides:
+                overrides["auto_respond"] = True
+            if "max_steps" not in overrides:
+                overrides["max_steps"] = 100
+
         if config:
             merged_agent_config = dict(self.agent_config)
             for item in config:
@@ -485,15 +554,13 @@ class EvalConfig(BaseModel):
             table.add_row(
                 "task_ids", ", ".join(self.task_ids[:5]) + ("..." if len(self.task_ids) > 5 else "")
             )
-        table.add_row("full", str(self.full))
-        table.add_row("max_steps", str(self.max_steps or (100 if self.full else 10)))
+        table.add_row("all", str(self.all))
+        table.add_row("max_steps", str(self.max_steps))
         if not self.remote:
             table.add_row("max_concurrent", str(self.max_concurrent))
         if self.group_size > 1:
             table.add_row("group_size", str(self.group_size))
-        # Show auto_respond when it will be true (explicit or via --full)
-        effective_auto_respond = self.auto_respond if self.auto_respond is not None else self.full
-        if effective_auto_respond:
+        if self.auto_respond:
             table.add_row("auto_respond", "[bold green]True[/bold green]")
         if self.very_verbose:
             table.add_row("very_verbose", "[bold green]True[/bold green]")
@@ -501,6 +568,10 @@ class EvalConfig(BaseModel):
             table.add_row("verbose", "[bold green]True[/bold green]")
         if self.remote:
             table.add_row("remote", "[bold green]True[/bold green] (submitting to platform)")
+        if self.gateway:
+            table.add_row("gateway", "[bold green]True[/bold green] (routing via HUD Gateway)")
+        if self.byok:
+            table.add_row("byok", "[bold green]True[/bold green] (remote only)")
 
         # Tool filters (only if set)
         if self.allowed_tools:
@@ -534,14 +605,14 @@ class EvalConfig(BaseModel):
             for name in config_cls.model_fields:
                 if name in skip:
                     continue
-                # Always show model (checkpoint_name)
-                if name == "checkpoint_name":
+                # Always show model
+                if name == "model":
                     if self.model:
                         value = self.model
                     elif overrides.get("model"):
                         value = overrides["model"]
                     else:
-                        value = getattr(defaults, "checkpoint_name", None)
+                        value = getattr(defaults, "model", None)
                     table.add_row("  model", str(value) if value else "—")
                 elif name in overrides:
                     value = overrides[name]
@@ -554,154 +625,108 @@ class EvalConfig(BaseModel):
         hud_console.console.print(table)
 
 
-# =============================================================================
-# Task loading
-# =============================================================================
-
-
-def _load_tasks_from_source(source: str) -> list[Task]:
-    """Load tasks from file or HuggingFace dataset."""
-    from hud.utils.tasks import load_tasks
-
-    path = Path(source)
-    if path.exists() and path.suffix in {".json", ".jsonl"}:
-        hud_console.info("📊 Loading task file…")
-        tasks = load_tasks(str(path))
-        try:
-            env_dir = find_environment_dir(path)
-            if env_dir is not None:
-                ensure_built(env_dir, interactive=False)
-        except Exception as exc:
-            hud_console.debug(f"Eval preflight env check skipped: {exc}")
-    else:
-        hud_console.info(f"📊 Loading tasks from: {source}…")
-        tasks = load_tasks(source)
-
-    if not tasks:
-        hud_console.error(f"No tasks found in: {source}")
-        raise typer.Exit(1)
-
-    return tasks  # type: ignore[return-value]
-
-
-def _warn_local_mcp(tasks: list[Task], source: str) -> None:
-    """Warn user if tasks use local MCP configs."""
-    try:
-        has_local = any(
-            isinstance(server_cfg, dict) and "command" in server_cfg and not server_cfg.get("url")
-            for t in tasks
-            for server_cfg in (getattr(t, "mcp_config", {}) or {}).values()
-            if isinstance(getattr(t, "mcp_config", {}), dict)
-        )
-
-        if not has_local:
-            return
-
-        hud_console.warning("Detected local MCP configurations (uses 'command' instead of 'url').")
-        hud_console.info("When running concurrently, exposed host ports from Docker may conflict.")
-
-        if not hud_console.confirm("Proceed with local MCP servers?", default=True):
-            hint_file = Path(source).name if Path(source).exists() else "<tasks_file>"
-            hud_console.hint(f"Convert to remote: hud convert {hint_file}")
-            raise typer.Exit(1)
-
-        hint_file = Path(source).name if Path(source).exists() else "<tasks_file>"
-        hud_console.hint(f"Convert to remote to avoid port conflicts: hud convert {hint_file}")
-
-    except typer.Exit:
-        raise
-    except Exception as e:
-        hud_console.debug(f"Local MCP check skipped: {e}")
-
-
 # =============================================================================
 # Evaluation runner
 # =============================================================================
 
 
-async def _run_evaluation(cfg: EvalConfig) -> tuple[list[Any], list[Task]]:
-    """Run evaluation with the given config."""
-    from hud.datasets import run_single_task, run_tasks
+async def _run_evaluation(cfg: EvalConfig) -> tuple[list[Any], list[Any]]:
+    """Run evaluation with the given config using run_dataset()."""
+    from hud.datasets import load_tasks, run_dataset
 
     if cfg.source is None or cfg.agent_type is None:
         raise ValueError("source and agent_type must be set")
 
-    tasks = _load_tasks_from_source(cfg.source)
+    # Load tasks using unified loader (handles v4→v5 conversion automatically)
+    hud_console.info(f"📊 Loading tasks from: {cfg.source}…")
+    tasks = load_tasks(cfg.source)
 
-    if not cfg.remote and (cfg.group_size > 1 or cfg.full):
-        _warn_local_mcp(tasks, cfg.source)
-
-    agent_kwargs = cfg.get_agent_kwargs()
-
-    path = Path(cfg.source)
-    dataset_name = path.name if path.exists() else cfg.source.split("/")[-1]
-    max_steps = cfg.max_steps or (100 if cfg.full else 10)
+    if not tasks:
+        hud_console.error(f"No tasks found in: {cfg.source}")
+        raise typer.Exit(1)
 
     # Filter by task IDs if provided
     if cfg.task_ids:
         id_set = set(cfg.task_ids)
-        filtered = [t for t in tasks if str(getattr(t, "id", "")) in id_set]
+        # Match by task.id or index
+        filtered = [t for i, t in enumerate(tasks) if t.id in id_set or str(i) in id_set]
         if not filtered:
             hud_console.error(f"No tasks found matching IDs: {', '.join(cfg.task_ids)}")
             raise typer.Exit(1)
         hud_console.info(f"Filtered to {len(filtered)} task(s) by ID")
         tasks = filtered
-    elif not cfg.full:
-        # Single task mode (no --full, no --task-ids)
+    elif not cfg.all:
+        # Single task mode (no --all, --full, or --task-ids)
         tasks = [tasks[0]]
         hud_console.info("Using first task (run with --full or --task-ids for more)…")
 
-    auto_respond = cfg.auto_respond if cfg.auto_respond is not None else cfg.full
+    hud_console.info(f"Loaded {len(tasks)} task(s)")
 
+    # Prepare agent kwargs
+    agent_kwargs = cfg.get_agent_kwargs()
+    auto_respond = cfg.auto_respond
     if auto_respond:
         agent_kwargs = {**agent_kwargs, "auto_respond": True}
 
+    max_steps = cfg.max_steps
+
+    # Remote execution - submit to HUD platform
     if cfg.remote:
-        hud_console.info(f"🚀 Submitting {len(tasks)} tasks for remote execution…")
-        await run_tasks(
+        agent_kwargs = {
+            k: v for k, v in agent_kwargs.items() if k not in ("api_key", "model_client")
+        }
+        # Create a job ID for tracking
+        import uuid
+
+        from hud.datasets.utils import submit_rollouts
+
+        job_id = str(uuid.uuid4())
+        hud_console.info(
+            f"Submitting {len(tasks)} task(s) for remote execution (job_id: {job_id})…"
+        )
+
+        await submit_rollouts(
             tasks=tasks,
+            job_id=job_id,
             agent_type=cfg.agent_type,
             agent_params=agent_kwargs,
-            name=f"Evaluation {dataset_name}",
-            metadata={"dataset": cfg.source},
             max_steps=max_steps,
             group_size=cfg.group_size,
-            remote=True,
+            use_byok=cfg.byok,
         )
+
+        hud_console.success(f"Tasks submitted. View at: https://hud.ai/jobs/{job_id}")
         return [], tasks
 
+    # Single task mode - show extra info
     if len(tasks) == 1 and cfg.group_size == 1:
-        task = tasks[0]
         logging.getLogger("hud.agents").setLevel(logging.INFO)
         logging.getLogger("hud.agents.base").setLevel(logging.INFO)
-
-        hud_console.info(task.prompt)
-        result = await run_single_task(
-            task=task,
-            agent_type=cfg.agent_type,
-            agent_params=agent_kwargs,
-            max_steps=max_steps,
-            trace_name=task.prompt,
+        # Get prompt from args (v4 tasks) or show scenario name
+        prompt = tasks[0].args.get("prompt") if tasks[0].args else tasks[0].scenario
+        if prompt:
+            hud_console.info(f"Prompt: {prompt}")
+    else:
+        hud_console.info(
+            f"🚀 Running evaluation (max_concurrent: {cfg.max_concurrent}, "
+            f"group_size: {cfg.group_size})…"
         )
-        hud_console.success(f"Reward: {result.reward}")
-        return [result], tasks
 
-    # Local batch execution
-    hud_console.info(
-        f"🚀 Running evaluation (max_concurrent: {cfg.max_concurrent}, "
-        f"group_size: {cfg.group_size})…"
-    )
-
-    results = await run_tasks(
-        tasks=tasks,
-        agent_type=cfg.agent_type,
+    # Run using run_dataset
+    results = await run_dataset(
+        tasks,
+        cfg.agent_type,
         agent_params=agent_kwargs,
-        name=f"Evaluation {dataset_name}",
-        max_concurrent=cfg.max_concurrent,
-        metadata={"dataset": cfg.source},
         max_steps=max_steps,
+        max_concurrent=cfg.max_concurrent,
         group_size=cfg.group_size,
+        quiet=cfg.quiet,
     )
+
+    # Show reward for single task
+    if len(tasks) == 1 and cfg.group_size == 1 and results:
+        hud_console.success(f"Reward: {results[0].reward}")
+
     return results, tasks
 
 
@@ -716,7 +741,12 @@ def eval_command(
         None,
         help="Agent: claude, openai, operator, gemini, gemini_cua, openai_compatible, integration_test",  # noqa: E501
     ),
-    full: bool = typer.Option(False, "--full", help="Run entire dataset"),
+    all: bool = typer.Option(False, "--all", help="Run all problems instead of just 1"),
+    full: bool = typer.Option(
+        False,
+        "--full",
+        help="Run the entire dataset. Shortcut for --all --auto-respond  --max-steps 100",
+    ),
     model: str | None = typer.Option(None, "--model", "-m", help="Model name"),
     config: list[str] | None = typer.Option(  # noqa: B008
         None, "--config", "-c", help="Agent config: key=value"
@@ -735,10 +765,10 @@ def eval_command(
     max_steps: int | None = typer.Option(None, "--max-steps", help="Max steps per task"),
     verbose: bool = typer.Option(False, "--verbose", "-v", help="Verbose output"),
     very_verbose: bool = typer.Option(False, "--very-verbose", "-vv", help="Debug logs"),
-    auto_respond: bool | None = typer.Option(
-        None,
+    auto_respond: bool = typer.Option(
+        False,
         "--auto-respond",
-        help="Continue without prompting after tool calls (default: True for --full)",
+        help="Automatically prompt the agent to continue if it does not respond with a tool call",
     ),
     group_size: int | None = typer.Option(None, "--group-size", help="Runs per task"),
     task_ids: str | None = typer.Option(None, "--task-ids", help="Comma-separated task IDs to run"),
@@ -746,6 +776,17 @@ def eval_command(
     remote: bool = typer.Option(
         False, "--remote", help="Submit tasks to platform for remote execution"
     ),
+    byok: bool = typer.Option(
+        False,
+        "--byok",
+        help="Remote only: use BYOK keys from encrypted env vars for inference",
+    ),
+    quiet: bool = typer.Option(
+        False, "--quiet", "-q", help="Suppress opening browser for eval links"
+    ),
+    gateway: bool = typer.Option(
+        False, "--gateway", "-g", help="Route LLM API calls through HUD Gateway"
+    ),
 ) -> None:
     """🚀 Run evaluation on datasets or individual tasks with agents.
 
@@ -755,6 +796,7 @@ def eval_command(
         hud eval tasks.json claude --config max_tokens=32768
         hud eval tasks.json openai --config temperature=0.7
         hud eval tasks.json claude --full --remote  # Remote execution
+        hud eval tasks.json claude --gateway  # Route LLM calls through HUD Gateway
     """
     hud_console.info("🔧 Initializing evaluation...")
 
@@ -763,6 +805,7 @@ def eval_command(
         source=source,
         agent=agent,
         model=model,
+        all=all,
         full=full,
         max_concurrent=max_concurrent,
         max_steps=max_steps,
@@ -775,6 +818,9 @@ def eval_command(
         group_size=group_size,
         config=config,
         remote=remote,
+        byok=byok,
+        quiet=quiet,
+        gateway=gateway,
     )
 
     # Find source if not provided
